#!/bin/bash

if [ x${CUDA_PATH} = x ]; then
	CUDA_SDK_PATH=/opt/CUDA3.1/NVIDIA_GPU_Computing_SDK
	DEVICE_QUERY=$CUDA_SDK_PATH/C/bin/linux/release/deviceQuery

	if [ ! -d $CUDA_SDK_PATH ]; then
	CUDA_SDK_PATH=/opt/CUDA4.0/NVIDIA_GPU_Computing_SDK
	DEVICE_QUERY=$CUDA_SDK_PATH/C/bin/linux/release/deviceQuery

	if [ ! -d $CUDA_SDK_PATH ]; then
	CUDA_SDK_PATH=/usr/local/cuda-5.0
	DEVICE_QUERY=$CUDA_SDK_PATH/samples/bin/linux/release/deviceQuery

	if [ ! -d $CUDA_SDK_PATH ]; then
	CUDA_SDK_PATH=/usr/local/cuda-5.5
	DEVICE_QUERY=$CUDA_SDK_PATH/samples/bin/x86_64/linux/release/deviceQuery

	if [ ! -d $CUDA_SDK_PATH ]; then
	CUDA_SDK_PATH=/usr/local/cuda-6.0
	DEVICE_QUERY=$CUDA_SDK_PATH/samples/bin/x86_64/linux/release/deviceQuery

	if [ ! -d $CUDA_SDK_PATH ]; then
	CUDA_SDK_PATH=/usr/local/cuda-6.5
	DEVICE_QUERY=$CUDA_SDK_PATH/samples/bin/x86_64/linux/release/deviceQuery

	if [ ! -d $CUDA_SDK_PATH ]; then
	CUDA_SDK_PATH=/usr/local/cuda
	DEVICE_QUERY=$CUDA_SDK_PATH/samples/bin/x86_64/linux/release/deviceQuery

	fi
	fi
	fi
	fi
	fi
	fi
else
	CUDA_SDK_PATH=$CUDA_PATH/NVIDIA_GPU_Computing_SDK
	if [ ! -d $CUDA_SDK_PATH ]; then
	CUDA_SDK_PATH=$CUDA_PATH
	fi
	DEVICE_QUERY=$CUDA_SDK_PATH/samples/bin/linux/release/deviceQuery
	if [ ! -e $DEVICE_QUERY ]; then
	DEVICE_QUERY=$CUDA_SDK_PATH/samples/bin/x86_64/linux/release/deviceQuery
	if [ ! -e $DEVICE_QUERY ]; then
		echo "deviceQuery is not found"
		exit 1
	fi
	fi
fi

if [ ! -e $DEVICE_QUERY ]; then
	echo "deviceQuery is not found"
	exit 1
fi

CUDA_CHECK=`$DEVICE_QUERY < /dev/null | \
	awk '/^FAILED/{print; exit}END{print "SUCCESS"}'`

DEV_QUERY=$DEVICE_QUERY
DEVICE_QUERY=do_c

do_c()
{
	if [ x${ASPEN_GPU_ID} = x ]; then
		ASPEN_GPU_ID=0
	fi
	`$DEV_QUERY` | awk 'BEGIN{flg=0}/^Device '$ASPEN_GPU_ID':/{flg=1}{if(flg)print}'
}


DEVICE=`$DEVICE_QUERY < /dev/null | \
	awk 'BEGIN{DEV=""}\
	/^Device/{\
		gsub(/^Device [0-9]+: /,"");\
		gsub(/^[ ]*\"/,"");\
		gsub(/\"[ ]*/,"");\
		gsub(/ /,"-"); \
		DEV=$1; print DEV; exit}\
	END{if(DEV=="")print "unknown"}'`

MP=`$DEVICE_QUERY < /dev/null | \
	awk 'BEGIN{MP=-1}\
		/multiprocessors/{\
			MP=$4; print MP; exit} \
		/Multiprocessors x Cores\/MP = Cores/{\
			MP=$6; print MP; exit}\
		/Multiprocessors x /{\
			gsub(/[\(\)]/,"");\
			MP=$1; print MP; exit}\
		/CUDA Cores/{\
			gsub(/[\(\)]/,"");\
			MP=$1; print MP; exit}\
		END{if(MP<0)print 0}'`

CG=`$DEVICE_QUERY < /dev/null | \
	awk 'BEGIN{CG=-1;}\
		/CUDA Capability Major/{\
			Major=$6}\
		/CUDA Capability Minor/{\
			Minor=$6;\
			CG=Major*100+Minor*10; print CG; exit}\
		/CUDA Capability Major\/Minor/{\
			gsub(/:/," ");Major=$6;Minor=$7;\
			CG=Major*100+Minor*10; print CG; exit}\
		END{if(CG<0)print 0}'`

MAXDIM=`$DEVICE_QUERY < /dev/null | \
		awk 'BEGIN{MAXDIM=-1;}\
		/global memory/{\
			gsub(/^.*global memory:/,"");\
			MAXDIM=$1; print MAXDIM; exit}\
		END{if(MAXDIM<0)print 0}' | \
		awk '{	MAXDIM=$1;\
			MAXDIM/=8.;\
			MAXDIM=sqrt(MAXDIM)*0.9;\
			MAXDIM=1000*int(MAXDIM);\
			print MAXDIM; exit}'`

MAXDIM2=`$DEVICE_QUERY < /dev/null | \
		awk 'BEGIN{MAXDIM=-1;}\
		/global memory/{\
			gsub(/^.*global memory:/,"");\
			MAXDIM=$1; print MAXDIM; exit}\
		END{if(MAXDIM<0)print 0}' | \
		awk '{	MAXDIM=$1;\
			MAXDIM/=4.;\
			MAXDIM=sqrt(MAXDIM)*0.9;\
			MAXDIM=1000*int(MAXDIM);\
			print MAXDIM; exit}'`

MAXDIM3=`$DEVICE_QUERY < /dev/null | \
		awk 'BEGIN{MAXDIM=-1;}\
		/global memory/{\
			gsub(/^.*global memory:/,"");\
			MAXDIM=$1; print MAXDIM; exit}\
		END{if(MAXDIM<0)print 0}' | \
		awk '{	MAXDIM=$1;\
			MAXDIM/=16.;\
			MAXDIM=sqrt(MAXDIM)*0.9;\
			MAXDIM=1000*int(MAXDIM);\
			print MAXDIM; exit}'`

echo 'DEVICE= '$DEVICE
echo 'MP= '$MP
echo 'CG= '$CG
echo 'MAXDIM= '$MAXDIM
echo 'MAXDIM2= '$MAXDIM2
echo 'MAXDIM3= '$MAXDIM3


